@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2025
+# Copyright (C) 2015-2026
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -322,19 +322,15 @@ class TestTransactionPartnerUserWithoutRequest(TransactionPartnerTestBase):
         assert json_dict["subscription_period"] == self.subscription_period.total_seconds()
         assert json_dict["premium_subscription_duration"] == self.premium_subscription_duration
 
-    def test_transaction_type_is_required_argument(self):
-        with pytest.raises(TypeError, match="`transaction_type` is a required argument"):
-            TransactionPartnerUser(user=self.user)
-
     def test_equality(self, transaction_partner_user):
         a = transaction_partner_user
         b = TransactionPartnerUser(
-            user=self.user,
             transaction_type=self.transaction_type,
+            user=self.user,
         )
         c = TransactionPartnerUser(
-            user=User(id=1, is_bot=False, first_name="user", last_name="user"),
             transaction_type=self.transaction_type,
+            user=User(id=1, is_bot=False, first_name="user", last_name="user"),
         )
         d = User(id=1, is_bot=False, first_name="user", last_name="user")
 
