@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 #  A library that provides a Python interface to the Telegram Bot API
-#  Copyright (C) 2015-2025
+#  Copyright (C) 2015-2026
 #  Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 #  This program is free software: you can redistribute it and/or modify
@@ -17,14 +17,15 @@
 #  You should have received a copy of the GNU Lesser Public License
 #  along with this program.  If not, see [http://www.gnu.org/licenses/].
 """Provides functions to test both methods."""
+
 import datetime as dtm
 import functools
 import inspect
 import re
 import zoneinfo
-from collections.abc import Collection, Iterable
+from collections.abc import Callable, Collection, Iterable
 from types import GenericAlias
-from typing import Any, Callable, ForwardRef, Optional, Union
+from typing import Any, ForwardRef
 
 import pytest
 
@@ -60,7 +61,7 @@ def check_shortcut_signature(
     bot_method: Callable,
     shortcut_kwargs: list[str],
     additional_kwargs: list[str],
-    annotation_overrides: Optional[dict[str, tuple[Any, Any]]] = None,
+    annotation_overrides: dict[str, tuple[Any, Any]] | None = None,
 ) -> bool:
     """
     Checks that the signature of a shortcut matches the signature of the underlying bot method.
@@ -80,7 +81,7 @@ def check_shortcut_signature(
     """
     annotation_overrides = annotation_overrides or {}
 
-    def resolve_class(class_name: str) -> Optional[type]:
+    def resolve_class(class_name: str) -> type | None:
         """Attempts to resolve a PTB class (telegram module only) from a ForwardRef.
 
         E.g. resolves <class 'telegram._files.sticker.StickerSet'> from "StickerSet".
@@ -139,6 +140,7 @@ def check_shortcut_signature(
                 for shortcut_arg, bot_arg in zip(
                     shortcut_sig.parameters[kwarg].annotation.__args__,
                     bot_sig.parameters[kwarg].annotation.__args__,
+                    strict=False,
                 ):
                     shortcut_arg_to_check = shortcut_arg  # for ruff
                     match = FORWARD_REF_PATTERN.search(str(shortcut_arg))
@@ -195,8 +197,8 @@ async def check_shortcut_call(
     shortcut_method: Callable,
     bot: ExtBot,
     bot_method_name: str,
-    skip_params: Optional[Iterable[str]] = None,
-    shortcut_kwargs: Optional[Iterable[str]] = None,
+    skip_params: Iterable[str] | None = None,
+    shortcut_kwargs: Iterable[str] | None = None,
 ) -> bool:
     """
     Checks that a shortcut passes all the existing arguments to the underlying bot method. Use as::
@@ -392,13 +394,13 @@ def make_assertion_for_link_preview_options(
             )
 
 
-def _check_forward_ref(obj: object) -> Union[str, object]:
+def _check_forward_ref(obj: object) -> str | object:
     if isinstance(obj, ForwardRef):
         return obj.__forward_arg__
     return obj
 
 
-def guess_return_type_name(method: Callable[[...], Any]) -> tuple[Union[str, object], bool]:
+def guess_return_type_name(method: Callable[[...], Any]) -> tuple[str | object, bool]:
     # Using typing.get_type_hints(method) would be the nicer as it also resolves ForwardRefs
     # and string annotations. But it also wants to resolve the parameter annotations, which
     # need additional namespaces and that's not worth the struggle for now …
