@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2025
+# Copyright (C) 2015-2026
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -21,6 +21,8 @@ import datetime as dtm
 import pytest
 
 from telegram import (
+    Bot,
+    BusinessBotRights,
     BusinessConnection,
     Chat,
     InputProfilePhotoStatic,
@@ -35,11 +37,19 @@ from telegram import (
 from telegram._files._inputstorycontent import InputStoryContentVideo
 from telegram._files.sticker import Sticker
 from telegram._gifts import AcceptedGiftTypes, Gift
+from telegram._inline.inlinekeyboardbutton import InlineKeyboardButton
+from telegram._inline.inlinekeyboardmarkup import InlineKeyboardMarkup
+from telegram._inputchecklist import InputChecklist, InputChecklistTask
+from telegram._message import Message
 from telegram._ownedgift import OwnedGiftRegular, OwnedGifts
+from telegram._reply import ReplyParameters
 from telegram._utils.datetime import UTC
 from telegram._utils.defaultvalue import DEFAULT_NONE
 from telegram.constants import InputProfilePhotoType, InputStoryContentType
+from telegram.ext import ExtBot
+from telegram.warnings import PTBDeprecationWarning
 from tests.auxil.files import data_file
+from tests.auxil.networking import OfflineRequest
 
 
 class BusinessMethodsTestBase:
@@ -51,10 +61,15 @@ class TestBusinessMethodsWithoutRequest(BusinessMethodsTestBase):
         user = User(1, "first", False)
         user_chat_id = 1
         date = dtm.datetime.utcnow()
-        can_reply = True
+        rights = BusinessBotRights(can_reply=True)
         is_enabled = True
         bc = BusinessConnection(
-            self.bci, user, user_chat_id, date, can_reply, is_enabled
+            self.bci,
+            user,
+            user_chat_id,
+            date,
+            is_enabled,
+            rights=rights,
         ).to_json()
 
         async def do_request(*args, **kwargs):
@@ -96,7 +111,10 @@ class TestBusinessMethodsWithoutRequest(BusinessMethodsTestBase):
             assert data.get("exclude_saved") is bool_param
             assert data.get("exclude_unlimited") is bool_param
             assert data.get("exclude_limited") is bool_param
+            assert data.get("exclude_limited_upgradable") is bool_param
+            assert data.get("exclude_limited_non_upgradable") is bool_param
             assert data.get("exclude_unique") is bool_param
+            assert data.get("exclude_from_blockchain") is bool_param
             assert data.get("sort_by_price") is bool_param
             assert data.get("offset") == offset
             assert data.get("limit") == limit
@@ -110,13 +128,50 @@ class TestBusinessMethodsWithoutRequest(BusinessMethodsTestBase):
             exclude_saved=bool_param,
             exclude_unlimited=bool_param,
             exclude_limited=bool_param,
+            exclude_limited_upgradable=bool_param,
+            exclude_limited_non_upgradable=bool_param,
             exclude_unique=bool_param,
+            exclude_from_blockchain=bool_param,
             sort_by_price=bool_param,
             offset=offset,
             limit=limit,
         )
         assert isinstance(obj, OwnedGifts)
 
+    @pytest.mark.parametrize("bot_class", [Bot, ExtBot])
+    async def test_get_business_account_gifts_exclude_limited_deprecation(
+        self, offline_bot, monkeypatch, bot_class
+    ):
+        bot = bot_class(offline_bot.token, request=OfflineRequest())
+
+        async def dummy_response(*args, **kwargs):
+            return OwnedGifts(
+                total_count=1,
+                gifts=[
+                    OwnedGiftRegular(
+                        gift=Gift(
+                            id="id1",
+                            sticker=Sticker(
+                                "file_id", "file_unique_id", 512, 512, False, False, "regular"
+                            ),
+                            star_count=5,
+                        ),
+                        send_date=dtm.datetime.now(tz=UTC).replace(microsecond=0),
+                        owned_gift_id="some_id_1",
+                    )
+                ],
+            ).to_dict()
+
+        monkeypatch.setattr(bot.request, "post", dummy_response)
+        with pytest.warns(PTBDeprecationWarning, match=r"9\.3.*exclude_limited") as record:
+            await bot.get_business_account_gifts(
+                business_connection_id=self.bci,
+                exclude_limited=True,
+            )
+
+        assert record[0].category == PTBDeprecationWarning
+        assert record[0].filename == __file__, "wrong stacklevel!"
+
     async def test_get_business_account_star_balance(self, offline_bot, monkeypatch):
         star_amount_json = StarAmount(amount=100, nanostar_amount=356).to_json()
 
@@ -203,7 +258,7 @@ class TestBusinessMethodsWithoutRequest(BusinessMethodsTestBase):
 
     async def test_set_business_account_gift_settings(self, offline_bot, monkeypatch):
         show_gift_button = True
-        accepted_gift_types = AcceptedGiftTypes(True, True, True, True)
+        accepted_gift_types = AcceptedGiftTypes(True, True, True, True, True)
 
         async def make_assertion(*args, **kwargs):
             data = kwargs.get("request_data").json_parameters
@@ -632,3 +687,201 @@ class TestBusinessMethodsWithoutRequest(BusinessMethodsTestBase):
 
         monkeypatch.setattr(offline_bot.request, "post", make_assertion)
         assert await offline_bot.delete_story(business_connection_id=self.bci, story_id=story_id)
+
+    async def test_send_checklist_all_args(self, offline_bot, monkeypatch):
+        chat_id = 123
+        checklist = InputChecklist(
+            title="My Checklist",
+            tasks=[InputChecklistTask(1, "Task 1"), InputChecklistTask(2, "Task 2")],
+        )
+        disable_notification = True
+        protect_content = False
+        message_effect_id = 42
+        reply_parameters = ReplyParameters(23, chat_id, allow_sending_without_reply=True)
+        reply_markup = InlineKeyboardMarkup(
+            [[InlineKeyboardButton(text="test", callback_data="test2")]]
+        )
+        json_message = Message(1, dtm.datetime.now(), Chat(1, ""), text="test").to_json()
+
+        async def make_assertions(*args, **kwargs):
+            params = kwargs.get("request_data").parameters
+            assert params.get("business_connection_id") == self.bci
+            assert params.get("chat_id") == chat_id
+            assert params.get("checklist") == checklist.to_dict()
+            assert params.get("disable_notification") is disable_notification
+            assert params.get("protect_content") is protect_content
+            assert params.get("message_effect_id") == message_effect_id
+            assert params.get("reply_parameters") == reply_parameters.to_dict()
+            assert params.get("reply_markup") == reply_markup.to_dict()
+
+            return 200, f'{{"ok": true, "result": {json_message}}}'.encode()
+
+        monkeypatch.setattr(offline_bot.request, "do_request", make_assertions)
+        obj = await offline_bot.send_checklist(
+            business_connection_id=self.bci,
+            chat_id=chat_id,
+            checklist=checklist,
+            disable_notification=disable_notification,
+            protect_content=protect_content,
+            message_effect_id=message_effect_id,
+            reply_parameters=reply_parameters,
+            reply_markup=reply_markup,
+        )
+        assert isinstance(obj, Message)
+
+    @pytest.mark.parametrize("default_bot", [{"disable_notification": True}], indirect=True)
+    @pytest.mark.parametrize(
+        ("passed_value", "expected_value"),
+        [(DEFAULT_NONE, True), (False, False), (None, None)],
+    )
+    async def test_send_checklist_default_disable_notification(
+        self, default_bot, monkeypatch, passed_value, expected_value
+    ):
+        async def make_assertion(url, request_data, *args, **kwargs):
+            assert request_data.parameters.get("disable_notification") is expected_value
+            return Message(1, dtm.datetime.now(), Chat(1, ""), text="test").to_dict()
+
+        monkeypatch.setattr(default_bot.request, "post", make_assertion)
+        kwargs = {
+            "business_connection_id": self.bci,
+            "chat_id": 123,
+            "checklist": InputChecklist(
+                title="My Checklist",
+                tasks=[InputChecklistTask(1, "Task 1")],
+            ),
+        }
+        if passed_value is not DEFAULT_NONE:
+            kwargs["disable_notification"] = passed_value
+
+        await default_bot.send_checklist(**kwargs)
+
+    @pytest.mark.parametrize("default_bot", [{"protect_content": True}], indirect=True)
+    @pytest.mark.parametrize(
+        ("passed_value", "expected_value"),
+        [(DEFAULT_NONE, True), (False, False), (None, None)],
+    )
+    async def test_send_checklist_default_protect_content(
+        self, default_bot, monkeypatch, passed_value, expected_value
+    ):
+        async def make_assertion(url, request_data, *args, **kwargs):
+            assert request_data.parameters.get("protect_content") is expected_value
+            return Message(1, dtm.datetime.now(), Chat(1, ""), text="test").to_dict()
+
+        monkeypatch.setattr(default_bot.request, "post", make_assertion)
+        kwargs = {
+            "business_connection_id": self.bci,
+            "chat_id": 123,
+            "checklist": InputChecklist(
+                title="My Checklist",
+                tasks=[InputChecklistTask(1, "Task 1")],
+            ),
+        }
+        if passed_value is not DEFAULT_NONE:
+            kwargs["protect_content"] = passed_value
+
+        await default_bot.send_checklist(**kwargs)
+
+    async def test_send_checklist_mutually_exclusive_reply_parameters(self, offline_bot):
+        """Test that reply_to_message_id and allow_sending_without_reply are mutually exclusive
+        with reply_parameters."""
+        with pytest.raises(ValueError, match="`reply_to_message_id` and"):
+            await offline_bot.send_checklist(
+                self.bci,
+                123,
+                InputChecklist(title="My Checklist", tasks=[InputChecklistTask(1, "Task 1")]),
+                reply_to_message_id=1,
+                reply_parameters=True,
+            )
+
+        with pytest.raises(ValueError, match="`allow_sending_without_reply` and"):
+            await offline_bot.send_checklist(
+                self.bci,
+                123,
+                InputChecklist(title="My Checklist", tasks=[InputChecklistTask(1, "Task 1")]),
+                allow_sending_without_reply=True,
+                reply_parameters=True,
+            )
+
+    async def test_edit_message_checklist_all_args(self, offline_bot, monkeypatch):
+        chat_id = 123
+        message_id = 45
+        checklist = InputChecklist(
+            title="My Checklist",
+            tasks=[InputChecklistTask(1, "Task 1"), InputChecklistTask(2, "Task 2")],
+        )
+        reply_markup = InlineKeyboardMarkup(
+            [[InlineKeyboardButton(text="test", callback_data="test2")]]
+        )
+        json_message = Message(1, dtm.datetime.now(), Chat(1, ""), text="test").to_json()
+
+        async def make_assertions(*args, **kwargs):
+            params = kwargs.get("request_data").parameters
+            assert params.get("business_connection_id") == self.bci
+            assert params.get("chat_id") == chat_id
+            assert params.get("message_id") == message_id
+            assert params.get("checklist") == checklist.to_dict()
+            assert params.get("reply_markup") == reply_markup.to_dict()
+
+            return 200, f'{{"ok": true, "result": {json_message}}}'.encode()
+
+        monkeypatch.setattr(offline_bot.request, "do_request", make_assertions)
+        obj = await offline_bot.edit_message_checklist(
+            business_connection_id=self.bci,
+            chat_id=chat_id,
+            message_id=message_id,
+            checklist=checklist,
+            reply_markup=reply_markup,
+        )
+        assert isinstance(obj, Message)
+
+    async def test_repost_story(self, offline_bot, monkeypatch):
+        """No way to test this without stories"""
+
+        async def make_assertion(url, request_data, *args, **kwargs):
+            for param in (
+                "business_connection_id",
+                "from_chat_id",
+                "from_story_id",
+                "active_period",
+                "post_to_chat_page",
+                "protect_content",
+            ):
+                assert request_data.parameters.get(param) == param
+            return Story(chat=Chat(id=1, type=Chat.PRIVATE), id=42).to_dict()
+
+        monkeypatch.setattr(offline_bot.request, "post", make_assertion)
+
+        story = await offline_bot.repost_story(
+            business_connection_id="business_connection_id",
+            from_chat_id="from_chat_id",
+            from_story_id="from_story_id",
+            active_period="active_period",
+            post_to_chat_page="post_to_chat_page",
+            protect_content="protect_content",
+        )
+        assert story.chat.id == 1
+        assert story.id == 42
+
+    @pytest.mark.parametrize("default_bot", [{"protect_content": True}], indirect=True)
+    @pytest.mark.parametrize(
+        ("passed_value", "expected_value"),
+        [(DEFAULT_NONE, True), (False, False), (None, None)],
+    )
+    async def test_repost_story_default_protect_content(
+        self, default_bot, monkeypatch, passed_value, expected_value
+    ):
+        async def make_assertion(url, request_data, *args, **kwargs):
+            assert request_data.parameters.get("protect_content") == expected_value
+            return Story(chat=Chat(123, "private"), id=123).to_dict()
+
+        monkeypatch.setattr(default_bot.request, "post", make_assertion)
+        kwargs = {
+            "business_connection_id": self.bci,
+            "from_chat_id": 123,
+            "from_story_id": 456,
+            "active_period": dtm.timedelta(seconds=20),
+        }
+        if passed_value is not DEFAULT_NONE:
+            kwargs["protect_content"] = passed_value
+
+        await default_bot.repost_story(**kwargs)
