@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2025
+# Copyright (C) 2015-2026
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -33,6 +33,8 @@ from telegram import (
     Location,
     ReactionTypeCustomEmoji,
     ReactionTypeEmoji,
+    UniqueGiftColors,
+    UserRating,
 )
 from telegram._gifts import AcceptedGiftTypes
 from telegram._utils.datetime import UTC, to_timestamp
@@ -87,6 +89,11 @@ def chat_full_info(bot):
         first_name=ChatFullInfoTestBase.first_name,
         last_name=ChatFullInfoTestBase.last_name,
         can_send_paid_media=ChatFullInfoTestBase.can_send_paid_media,
+        is_direct_messages=ChatFullInfoTestBase.is_direct_messages,
+        parent_chat=ChatFullInfoTestBase.parent_chat,
+        rating=ChatFullInfoTestBase.rating,
+        unique_gift_colors=ChatFullInfoTestBase.unique_gift_colors,
+        paid_message_star_count=ChatFullInfoTestBase.paid_message_star_count,
     )
     chat.set_bot(bot)
     chat._unfreeze()
@@ -145,8 +152,19 @@ class ChatFullInfoTestBase:
     first_name = "first_name"
     last_name = "last_name"
     can_send_paid_media = True
-    can_send_gift = True
-    accepted_gift_types = AcceptedGiftTypes(True, True, True, True)
+    accepted_gift_types = AcceptedGiftTypes(True, True, True, True, True)
+    is_direct_messages = True
+    parent_chat = Chat(4, "channel", "channel")
+    rating = UserRating(level=1, rating=2, current_level_rating=3, next_level_rating=4)
+    unique_gift_colors = UniqueGiftColors(
+        model_custom_emoji_id="model_custom_emoji_id",
+        symbol_custom_emoji_id="symbol_custom_emoji_id",
+        light_theme_main_color=0xFF5733,
+        light_theme_other_colors=[0x33FF57, 0x3357FF],
+        dark_theme_main_color=0xC70039,
+        dark_theme_other_colors=[0x900C3F, 0x581845],
+    )
+    paid_message_star_count = 1234
 
 
 class TestChatFullInfoWithoutRequest(ChatFullInfoTestBase):
@@ -166,7 +184,6 @@ class TestChatFullInfoWithoutRequest(ChatFullInfoTestBase):
             "max_reaction_count": self.max_reaction_count,
             "username": self.username,
             "accepted_gift_types": self.accepted_gift_types.to_dict(),
-            "can_send_gift": self.can_send_gift,
             "sticker_set_name": self.sticker_set_name,
             "can_set_sticker_set": self.can_set_sticker_set,
             "permissions": self.permissions.to_dict(),
@@ -203,6 +220,11 @@ class TestChatFullInfoWithoutRequest(ChatFullInfoTestBase):
             "first_name": self.first_name,
             "last_name": self.last_name,
             "can_send_paid_media": self.can_send_paid_media,
+            "is_direct_messages": self.is_direct_messages,
+            "parent_chat": self.parent_chat.to_dict(),
+            "rating": self.rating.to_dict(),
+            "unique_gift_colors": self.unique_gift_colors.to_dict(),
+            "paid_message_star_count": self.paid_message_star_count,
         }
 
         cfi = ChatFullInfo.de_json(json_dict, offline_bot)
@@ -252,6 +274,11 @@ class TestChatFullInfoWithoutRequest(ChatFullInfoTestBase):
         assert cfi.last_name == self.last_name
         assert cfi.max_reaction_count == self.max_reaction_count
         assert cfi.can_send_paid_media == self.can_send_paid_media
+        assert cfi.is_direct_messages == self.is_direct_messages
+        assert cfi.parent_chat == self.parent_chat
+        assert cfi.rating == self.rating
+        assert cfi.unique_gift_colors == self.unique_gift_colors
+        assert cfi.paid_message_star_count == self.paid_message_star_count
 
     def test_de_json_localization(self, offline_bot, raw_bot, tz_bot):
         json_dict = {
@@ -333,35 +360,11 @@ class TestChatFullInfoWithoutRequest(ChatFullInfoTestBase):
         assert cfi_dict["accepted_gift_types"] == cfi.accepted_gift_types.to_dict()
 
         assert cfi_dict["max_reaction_count"] == cfi.max_reaction_count
-
-    def test_accepted_gift_types_is_required_argument(self):
-        with pytest.raises(TypeError, match="`accepted_gift_type` is a required argument"):
-            ChatFullInfo(
-                id=123,
-                type=Chat.PRIVATE,
-                accent_color_id=1,
-                max_reaction_count=2,
-                can_send_gift=True,
-            )
-
-    def test_can_send_gift_deprecation_warning(self):
-        with pytest.warns(
-            PTBDeprecationWarning,
-            match="'can_send_gift' was replaced by 'accepted_gift_types' in Bot API 9.0",
-        ):
-            chat_full_info = ChatFullInfo(
-                id=123,
-                type=Chat.PRIVATE,
-                accent_color_id=1,
-                max_reaction_count=2,
-                accepted_gift_types=self.accepted_gift_types,
-                can_send_gift=self.can_send_gift,
-            )
-        with pytest.warns(
-            PTBDeprecationWarning,
-            match="Bot API 9.0 renamed the attribute 'can_send_gift' to 'accepted_gift_types'",
-        ):
-            chat_full_info.can_send_gift
+        assert cfi_dict["is_direct_messages"] == cfi.is_direct_messages
+        assert cfi_dict["parent_chat"] == cfi.parent_chat.to_dict()
+        assert cfi_dict["rating"] == cfi.rating.to_dict()
+        assert cfi_dict["unique_gift_colors"] == cfi.unique_gift_colors.to_dict()
+        assert cfi_dict["paid_message_star_count"] == cfi.paid_message_star_count
 
     def test_time_period_properties(self, PTB_TIMEDELTA, chat_full_info):
         cfi = chat_full_info
