@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2025
+# Copyright (C) 2015-2026
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -18,7 +18,6 @@
 # along with this program. If not, see [http://www.gnu.org/licenses/].
 
 import datetime as dtm
-from collections.abc import Sequence
 from copy import deepcopy
 
 import pytest
@@ -61,6 +60,7 @@ class OwnedGiftTestBase:
         star_count=5,
     )
     unique_gift = UniqueGift(
+        gift_id="gift_id",
         base_name="human_readable",
         name="unique_name",
         number=10,
@@ -96,6 +96,9 @@ class OwnedGiftTestBase:
     prepaid_upgrade_star_count = 200
     can_be_transferred = True
     transfer_star_count = 300
+    next_transfer_date = dtm.datetime.now(tz=UTC).replace(microsecond=0)
+    is_upgrade_separate = False
+    unique_gift_number = 37
 
 
 class TestOwnedGiftWithoutRequest(OwnedGiftTestBase):
@@ -139,6 +142,7 @@ class TestOwnedGiftWithoutRequest(OwnedGiftTestBase):
             "prepaid_upgrade_star_count": self.prepaid_upgrade_star_count,
             "can_be_transferred": self.can_be_transferred,
             "transfer_star_count": self.transfer_star_count,
+            "next_transfer_date": to_timestamp(self.next_transfer_date),
         }
         og = OwnedGift.de_json(json_dict, offline_bot)
 
@@ -182,6 +186,8 @@ def owned_gift_regular():
         was_refunded=TestOwnedGiftRegularWithoutRequest.was_refunded,
         convert_star_count=TestOwnedGiftRegularWithoutRequest.convert_star_count,
         prepaid_upgrade_star_count=TestOwnedGiftRegularWithoutRequest.prepaid_upgrade_star_count,
+        is_upgrade_separate=TestOwnedGiftRegularWithoutRequest.is_upgrade_separate,
+        unique_gift_number=TestOwnedGiftRegularWithoutRequest.unique_gift_number,
     )
 
 
@@ -208,6 +214,8 @@ class TestOwnedGiftRegularWithoutRequest(OwnedGiftTestBase):
             "was_refunded": self.was_refunded,
             "convert_star_count": self.convert_star_count,
             "prepaid_upgrade_star_count": self.prepaid_upgrade_star_count,
+            "is_upgrade_separate": self.is_upgrade_separate,
+            "unique_gift_number": self.unique_gift_number,
         }
         ogr = OwnedGiftRegular.de_json(json_dict, offline_bot)
         assert ogr.gift == self.gift
@@ -222,6 +230,8 @@ class TestOwnedGiftRegularWithoutRequest(OwnedGiftTestBase):
         assert ogr.was_refunded == self.was_refunded
         assert ogr.convert_star_count == self.convert_star_count
         assert ogr.prepaid_upgrade_star_count == self.prepaid_upgrade_star_count
+        assert ogr.is_upgrade_separate == self.is_upgrade_separate
+        assert ogr.unique_gift_number == self.unique_gift_number
         assert ogr.api_kwargs == {}
 
     def test_to_dict(self, owned_gift_regular):
@@ -240,6 +250,8 @@ class TestOwnedGiftRegularWithoutRequest(OwnedGiftTestBase):
         assert json_dict["was_refunded"] == self.was_refunded
         assert json_dict["convert_star_count"] == self.convert_star_count
         assert json_dict["prepaid_upgrade_star_count"] == self.prepaid_upgrade_star_count
+        assert json_dict["is_upgrade_separate"] == self.is_upgrade_separate
+        assert json_dict["unique_gift_number"] == self.unique_gift_number
 
     def test_parse_entity(self, owned_gift_regular):
         entity = MessageEntity(MessageEntity.BOLD, 0, 4)
@@ -292,6 +304,7 @@ def owned_gift_unique():
         is_saved=TestOwnedGiftUniqueWithoutRequest.is_saved,
         can_be_transferred=TestOwnedGiftUniqueWithoutRequest.can_be_transferred,
         transfer_star_count=TestOwnedGiftUniqueWithoutRequest.transfer_star_count,
+        next_transfer_date=TestOwnedGiftUniqueWithoutRequest.next_transfer_date,
     )
 
 
@@ -313,6 +326,7 @@ class TestOwnedGiftUniqueWithoutRequest(OwnedGiftTestBase):
             "is_saved": self.is_saved,
             "can_be_transferred": self.can_be_transferred,
             "transfer_star_count": self.transfer_star_count,
+            "next_transfer_date": to_timestamp(self.next_transfer_date),
         }
         ogu = OwnedGiftUnique.de_json(json_dict, offline_bot)
         assert ogu.gift == self.unique_gift
@@ -322,6 +336,7 @@ class TestOwnedGiftUniqueWithoutRequest(OwnedGiftTestBase):
         assert ogu.is_saved == self.is_saved
         assert ogu.can_be_transferred == self.can_be_transferred
         assert ogu.transfer_star_count == self.transfer_star_count
+        assert ogu.next_transfer_date == self.next_transfer_date
         assert ogu.api_kwargs == {}
 
     def test_to_dict(self, owned_gift_unique):
@@ -335,6 +350,7 @@ class TestOwnedGiftUniqueWithoutRequest(OwnedGiftTestBase):
         assert json_dict["is_saved"] == self.is_saved
         assert json_dict["can_be_transferred"] == self.can_be_transferred
         assert json_dict["transfer_star_count"] == self.transfer_star_count
+        assert json_dict["next_transfer_date"] == to_timestamp(self.next_transfer_date)
 
     def test_equality(self, owned_gift_unique):
         a = owned_gift_unique
@@ -365,7 +381,7 @@ def owned_gifts(request):
 class OwnedGiftsTestBase:
     total_count = 2
     next_offset = "next_offset_str"
-    gifts: Sequence[OwnedGifts] = [
+    gifts: list[OwnedGift] = [
         OwnedGiftRegular(
             gift=Gift(
                 id="id1",
@@ -388,6 +404,7 @@ class OwnedGiftsTestBase:
         ),
         OwnedGiftUnique(
             gift=UniqueGift(
+                gift_id="gift_id",
                 base_name="human_readable",
                 name="unique_name",
                 number=10,
